<?php
/**
 * Theme functions and definitions
 *
 * @package Businessmatic
 */

/**
 * After setup theme hook
 */
function businessmatic_theme_setup(){
    /*
     * Make chile theme available for translation.
     * Translations can be filed in the /languages/ directory.
     */
    load_child_theme_textdomain( 'businessmatic', get_stylesheet_directory() . '/languages' );
}
add_action( 'after_setup_theme', 'businessmatic_theme_setup' );

/**
 * Load assets.
 *
 */
function businessmatic_enqueue_styles_and_scripts() {
    $my_theme = wp_get_theme();
    $version = $my_theme['Version'];
    
    wp_enqueue_style( 'rara-business-style', get_template_directory_uri() . '/style.css' );
    wp_enqueue_style( 'businessmatic-style', get_stylesheet_directory_uri() . '/style.css', array( 'rara-business-style' ), $version );
}
add_action( 'wp_enqueue_scripts', 'businessmatic_enqueue_styles_and_scripts' );

/**
 * Creative Business Header Image
 */
function businessmatic_custom_header_args_callback(){
    $default_image = array(
        'default-image'    => get_stylesheet_directory_uri().'/images/banner-image.jpg',
    ); 
    return $default_image;
}
add_filter( 'rara_business_custom_header_args', 'businessmatic_custom_header_args_callback' );

/**
 * Add demo content info
 */
function rara_business_customizer_demo_content( $wp_customize ) {
        
    $wp_customize->add_section( 'demo_content_section' , array(
        'title'       => __( 'Demo Content Import' , 'businessmatic' ),
        'priority'    => 7,
        ));
        
    $wp_customize->add_setting(
        'demo_content_instruction',
        array(
            'sanitize_callback' => 'wp_kses_post'
        )
    );

    /* translators: 1: string, 2: url, 3: string */
    $demo_content_description = sprintf( '%1$s<a class="documentation" href="%2$s" target="_blank">%3$s</a>', esc_html__( 'Businessmatic comes with demo content import feature. You can import the demo content with just one click. For step-by-step video tutorial, ', 'businessmatic' ), esc_url( 'https://rarathemes.com/blog/import-demo-content-rara-themes/' ), esc_html__( 'Click here', 'businessmatic' ) );

    $wp_customize->add_control(
        new Rara_Business_Note_Control( 
            $wp_customize,
            'demo_content_instruction',
            array(
                'section'       => 'demo_content_section',
                'description'   => $demo_content_description
            )
        )
    );

    $theme_demo_content_desc = '';
    
    $theme_demo_content_desc .= '<span class="sticky_info_row download-link"><label class="row-element">' . __( 'Download Demo Content', 'businessmatic' ) . ': </label><a href="' . esc_url( 'https://docs.rarathemes.com/docs/businessmatic/theme-activation-and-installation/how-to-import-demo-content/' ) . '" target="_blank">' . __( 'Click here', 'businessmatic' ) . '</a></span><br />';
    
    if( ! class_exists( 'RDDI_init' ) ) {
        $theme_demo_content_desc .= '<span class="sticky_info_row"><label class="row-element">' . __( 'Plugin required', 'businessmatic' ) . ': </label><a href="' . esc_url( 'https://wordpress.org/plugins/rara-one-click-demo-import/' ) . '" target="_blank">' . __( 'Rara One Click Demo Import', 'businessmatic' ) . '</a></span><br />';
    }

    $wp_customize->add_setting( 'theme_demo_content_info',array(
        'default'           => '',
        'sanitize_callback' => 'wp_kses_post',
        ));

    // Demo content 
    $wp_customize->add_control( new Rara_Business_Note_Control( $wp_customize ,'theme_demo_content_info',array(
        'section'     => 'demo_content_section',
        'description' => $theme_demo_content_desc
        )));

}
add_action( 'customize_register', 'rara_business_customizer_demo_content', 15 );

/**
 * Header Start
*/
function rara_business_header(){ 
    $default_options = rara_business_default_theme_options(); // Get default theme options

    $ed_header_contact = get_theme_mod( 'ed_header_contact_details', $default_options['ed_header_contact_details'] );
    $phone             = get_theme_mod( 'header_phone', $default_options['header_phone'] );
    $address           = get_theme_mod( 'header_address', $default_options['header_address'] );
    $email             = get_theme_mod( 'header_email', $default_options['header_email'] );
    $icon              = get_theme_mod( 'custom_link_icon', $default_options['custom_link_icon'] );
    $label             = get_theme_mod( 'custom_link_label', $default_options['custom_link_label'] );
    $ed_header_social  = get_theme_mod( 'ed_header_social_links', $default_options['ed_header_social_links'] );
    $social_links      = get_theme_mod( 'header_social_links', $default_options['header_social_links'] );
    $link              = get_theme_mod( 'custom_link', $default_options['custom_link'] );

    ?>    
    <header id="masthead" class="site-header center-layout" itemscope itemtype="https://schema.org/WPHeader">
        <?php 
            if( ! ( ( $phone || $address || $email ) && $ed_header_contact ) &&  ! ( $ed_header_social && ! empty( $social_links ) ) ){ 
                $class = ' hide-header-top';
            } else {
                $class ='';
            }
        ?>
		<div class="header-t<?php echo esc_attr( $class ); ?>">
			<div class="container">
				<?php 
                if( ( $phone || $address || $email ) && $ed_header_contact ){ ?>
                    <div class="contact-info">
    					<?php 
                            if( $phone ) rara_business_header_phone( $phone );
                            if( $address ) rara_business_header_address( $address );
                            if( $email ) rara_business_header_email( $email ); 
                        ?>
    				</div>
                    <?php 
                } 
                
                rara_business_social_links( $ed_header_social, $social_links );
                ?>
                
				<button id="primary-toggle-button" data-toggle-target=".main-menu-modal" data-toggle-body-class="showing-main-menu-modal" aria-expanded="false" data-set-focus=".close-main-nav-toggle">
					<span></span>
					<span></span>
					<span></span>
				</button>
			</div>
            
			<?php rara_business_mobile_header(); ?>
		</div>

		<div class="main-header">
			<div class="container">
                <?php rara_business_site_branding(); ?>
				<div class="right">
                    <?php 
                        rara_business_header_navigation();
                        if( $link && $label ) rara_business_custom_link( $icon, $link, $label ); 
                    ?>
				</div>
			</div>
		</div>
	</header>
    <?php 
}

/**
 * Footer Bottom
*/
function rara_business_footer_bottom(){ ?>
    <div class="footer-b">      
        <?php
            rara_business_get_footer_copyright();
            echo '<span class="by">';
            echo esc_html__( 'Businessmatic | Developed By ', 'businessmatic' ); 
            echo '<a href="' . esc_url( 'https://rarathemes.com/' ) .'" rel="nofollow" target="_blank">' . esc_html__( 'Rara Themes', 'businessmatic' ) . '</a>.';
            echo '</span>';
            
            /* translators: 1: poweredby, 2: link, 3: span tag closed  */
            printf( esc_html__( ' %1$sPowered by %2$s%3$s', 'businessmatic' ), '<span class="powered-by">', '<a href="'. esc_url( __( 'https://wordpress.org/', 'businessmatic' ) ) .'" target="_blank">WordPress</a>.', '</span>' );

            if ( function_exists( 'the_privacy_policy_link' ) ) {
                the_privacy_policy_link( '<span class="policy_link">', '</span>');
            }
        ?>      
    </div>
    <?php
}

/**
 * Register custom fonts.
 */
function rara_business_fonts_url() {
    $fonts_url = '';

    /* 
     * Translators: If there are characters in your language that are not
     * supported by Poppins fonts, translate this to 'off'. Do not translate
     * into your own language.
    */
    $poppins_font = _x( 'on', 'Poppins font: on or off', 'businessmatic' );

    if ( 'off' !== $poppins_font ) {
        $font_families = array();

        if ( 'off' !== $poppins_font ) {
            $font_families[] = 'Poppins:100,100i,300,300i,400,400i,700,700i,900,900i';
        }

        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
            'display' => urlencode( 'fallback' ),
        );

        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }

    return esc_url( $fonts_url );
}