<?php

/*-----------------------------------------------------------------------------------*/
// Add Theme Stylesheets to Page head
/*-----------------------------------------------------------------------------------*/
add_action( 'wp_enqueue_scripts', 'solostream_enqueue_styles' );
function solostream_enqueue_styles() {
	wp_enqueue_style( 'theme-main-styles', get_stylesheet_uri() );
	wp_enqueue_style( 'theme-fonts-styles', get_template_directory_uri(). '/style-font.css' );
	if (get_option('solostream_responsive_off') != 'Yes') {
		wp_enqueue_style( 'theme-responsive-styles', get_template_directory_uri(). '/style-responsive.css' );
	}
}


/*-----------------------------------------------------------------------------------*/
// Add Custom Stylesheet to Page head
/*-----------------------------------------------------------------------------------*/
add_action( 'wp_enqueue_scripts', 'solostream_enqueue_custom_styles', 99 );
function solostream_enqueue_custom_styles() {
	wp_enqueue_style( 'theme-custom-styles', get_template_directory_uri(). '/custom.css' );
}


/*-----------------------------------------------------------------------------------*/
// Add Viewport Meta Tag
/*-----------------------------------------------------------------------------------*/
add_action('wp_head','solostream_viewport_meta');
function solostream_viewport_meta() {
	if ( get_option('solostream_responsive_off') != 'Yes'  ) {
		echo '<meta name="viewport" content="width=device-width,initial-scale=1" />';
	}
}

/*-----------------------------------------------------------------------------------*/
// Custom Styling from Theme Settings
/*-----------------------------------------------------------------------------------*/

add_action('wp_head','solostream_custom_styling');
function solostream_custom_styling() {

	global $solostream_options;
	$output = '';

// Body Styles

	$body = '';
	$body_bg = get_option('solostream_body_backgroundcolor');
	$body_bg_image = get_option('solostream_custom_body_bg_image');
	$body_bg_image_repeat = get_option('solostream_custom_body_bg_image_repeat');
	$body_bg_image_attach = get_option('solostream_custom_body_bg_image_attachment');
	$body_bg_image_position = get_option('solostream_custom_body_bg_image_position');
	$body_font = get_option('solostream_body_font_family');
	$body_font_color = get_option('solostream_body_font_color');
	$body_link_color = get_option('solostream_body_link_color');
	$body_link_hover_color = get_option('solostream_body_link_hover_color');

	if ( $body_bg )
		$body .= 'background-color:'.$body_bg.';';
	if ( $body_bg_image )
		$body .= 'background-image:url('.$body_bg_image.') !important;background-repeat:'.$body_bg_image_repeat.';background-attachment:'.$body_bg_image_attach.';background-position:'.$body_bg_image_position.';';
	if ( $body_font )
		$body .= 'font-family:'.$body_font.';';
	if ( $body_font_color )
		$body .= 'color:'.$body_font_color.';';

	if ( $body != '' )
		$output .= 'body, #outer-wrap {'.$body.';} #wrap {background:#fff; padding: 0 20px 0 20px;} #page {margin-top:-30px;} #contentleft {padding-top:29px} #contentright {margin-top:0}'. "\n";

	if ( $body_link_color )
		$output .= 'a,a:link,a:visited {color:'.$body_link_color.';}' . "\n";
	if ( $body_link_hover_color )
		$output .= 'a:hover,a:active {color:'.$body_link_hover_color.';}' . "\n";

// Post Title Styles

	$post_title_font = get_option('solostream_post_title_font');
	$post_title_weight = get_option('solostream_post_title_weight');
	$post_title_link_color = get_option('solostream_post_title_link_color');
	$post_title_link_hover_color = get_option('solostream_post_title_link_hover_color');

	if ( $post_title_font )
		$output .= 'h1.post-title, h2.post-title, h3.post-title, p.post-title {font-family:'.$post_title_font.';}' . "\n";
	if ( $post_title_weight )
		$output .= 'h1.post-title, h2.post-title, h3.post-title, p.post-title {font-weight:'.$post_title_weight.';}' . "\n";
	if ( $post_title_link_color )
		$output .= '.post-title a,.post-title a:link,.post-title a:visited {color:'.$post_title_link_color.' !important;}' . "\n";
	if ( $post_title_link_hover_color )
		$output .= '.post-title a:hover,.post-title a:active {color:'.$post_title_link_hover_color.' !important;}' . "\n";

// Advanced Styles

	$overall_color = get_option('solostream_overall_color');
	$widgettitle_font_color = get_option('solostream_widgettitle_font_color');
	$widgettitle_font_size = get_option('solostream_widgettitle_font_size');
	$ribbon_heading_color = get_option('solostream_ribbon_heading_color');
	$ribbon_heading_font_color = get_option('solostream_ribbon_heading_font_color');
	$ribbon_heading_font_size = get_option('solostream_ribbon_heading_font_size');
	$subscribebox_border_color = get_option('solostream_subscribebox_border_color');

	if ( $overall_color )
		$output .= '#header, #header-image-logo, h2.feature-title, #footer-widgets, .widget.subscribebox, .widget.subscribebox .widget-wrap, .date-box, ul#filter a, ul#filter li a:hover, ul#filter li.current a, .portfolio-text a:hover, .portfolio-text a:active, .featured.cat .cat-container a.more-link:hover, .widget.sidetabs .flextabs-custom-controls a, .widget.sidetabs .flextabs-custom-controls a:link, .widget.sidetabs .flextabs-custom-controls a:visited, .widget.sidetabs .flextabs-custom-controls a.flex-active, .widget.sidetabs .flextabs-custom-controls a.flex-active:link, .widget.sidetabs .flextabs-custom-controls a.flex-active:visited, #commentform input[type="submit"],#commentform input[type="button"],.archive-tabs a,.archive-tabs a:link,.archive-tabs a:visited,.email-form input[type="submit"],.email-form input[type="button"],#searchform input[type="submit"],#searchform input[type="button"],.wpcf7 input[type="submit"],.wpcf7 input[type="button"] {background-color:'.$overall_color.'}' . "\n";
	if ( $widgettitle_font_color )
		$output .= 'h3.widgettitle {color:'.$widgettitle_font_color.';}' . "\n";
	if ( $widgettitle_font_size )
		$output .= 'h3.widgettitle {font-size:'.$widgettitle_font_size.';}' . "\n";
	if ( $ribbon_heading_color )
		$output .= 'h2.feature-title {background-color:'.$ribbon_heading_color.';}' . "\n";
	if ( $ribbon_heading_font_size )
		$output .= 'h2.feature-title {font-size:'.$ribbon_heading_font_size.';}' . "\n";
	if ( $ribbon_heading_font_color )
		$output .= 'h2.feature-title span {color:'.$ribbon_heading_font_color.';}' . "\n";
	if ( $subscribebox_border_color )
		$output .= '.widget.subscribebox {background-color:'.$subscribebox_border_color.';}' . "\n";

// Date Box Styles

	$date_box = '';
	$date_box_bg_color = get_option('solostream_date_box_bg_color');
	$date_box_font_family = get_option('solostream_date_box_font_family');
	$date_box_font_color = get_option('solostream_date_box_font_color');
	$date_box_font_size = get_option('solostream_date_box_font_size');
	$date_box_font_weight = get_option('solostream_date_box_font_weight');

	if ( $date_box_font_family )
		$date_box .= 'font-family:'.$date_box_font_family.';';
	if ( $date_box_bg_color )
		$date_box .= 'background-color:'.$date_box_bg_color.'; background-image:none;';
	if ( $date_box_font_color )
		$date_box .= 'color:'.$date_box_font_color.';';
	if ( $date_box_font_size )
		$date_box .= 'font-size:'.$date_box_font_size.';';
	if ( $date_box_font_weight )
		$date_box .= 'font-weight:'.$date_box_font_weight.';';

	if ( $date_box != '' )
		$output .= '.date-box {'.$date_box.'}'. "\n";

// Site Title Styles

	$sitetitle = '';
	$site_title_size = get_option('solostream_site_title_size');
	$site_title_weight = get_option('solostream_site_title_weight');
	$site_title_font = get_option('solostream_site_title_font_family');
	$site_title_color = get_option('solostream_site_title_color');
	$site_title_align = get_option('solostream_site_title_align');

	if ( $site_title_align )
		$output .= '#header-image-logo #sitetitle {float:'.$site_title_align.';}' . "\n";

	if ( $site_title_size )
		$sitetitle .= 'font-size:'.$site_title_size.';';
	if ( $site_title_weight )
		$sitetitle .= 'font-weight:'.$site_title_weight.';';
	if ( $site_title_font )
		$sitetitle_font .= 'font-family:'.$site_title_font.';';

	if ( $sitetitle != '' )
		$output .= '#sitetitle .title, #sitetitle .title a {'.$sitetitle.';}'. "\n";
	if ( $sitetitle_font != '' )
		$output .= '#sitetitle .title {'.$sitetitle_font.';}'. "\n";

	if ( $site_title_color )
		$output .= '#sitetitle .title, #sitetitle .title a {color:'.$site_title_color.';}' . "\n";

// Tagline Styles

	$tagline = '';
	$tagline_size = get_option('solostream_tagline_size');
	$tagline_weight = get_option('solostream_tagline_weight');
	$tagline_font = get_option('solostream_tagline_font_family');
	$tagline_color = get_option('solostream_tagline_color');

	if ( $tagline_size )
		$tagline .= 'font-size:'.$tagline_size.';';
	if ( $tagline_weight )
		$tagline .= 'font-weight:'.$tagline_weight.';';
	if ( $tagline_font )
		$tagline .= 'font-family:'.$tagline_font.';';

	if ( $tagline != '' )
		$output .= '#sitetitle .description {'.$tagline.'}'. "\n";

	if ( $tagline_color )
		$output .= '#sitetitle .description {color:'.$tagline_color.';}' . "\n";

// Site Title Logo Styles

	$site_title_option = get_option('solostream_site_title_option');
	$site_logo_url = get_option('solostream_site_logo_url');
	$site_logo_position = get_option('solostream_site_logo_position');
	$site_logo_height = get_option('solostream_site_logo_height');
	$site_title_bg_color = get_option('solostream_site_title_bg_color');
	$head_banner = get_option('solostream_ad468head');

	global $post;
	if ( $head_banner == "yes" || is_singular() && get_post_meta($post->ID, 'ad468_header', true) )
		$output .= '@media only screen and (min-width: 801px) { .centercatnav #sitetitle, #sitetitle {float:left;max-width:49%;margin:0 0 20px;text-align:left;clear:left;} }' . "\n";
	if ( $site_title_bg_color )
		$output .= '#header, #header-image-logo {background-color:'.$site_title_bg_color.';}' . "\n";

// Top Navigation Adjustments

	$topnav = '';
	$topnav_size = get_option('solostream_topnav_size');
	$topnav_weight = get_option('solostream_topnav_weight');
	$topnav_font = get_option('solostream_topnav_font_family');
	$topnav_bg_color = get_option('solostream_topnav_bg_color');
	$topnav_link_color = get_option('solostream_topnav_link_color');
	$topnav_link_hover_color = get_option('solostream_topnav_link_hover_color');
	$topnav_link_hover_bg_color = get_option('solostream_topnav_link_hover_bg_color');
	$topnav_current_link_color = get_option('solostream_topnav_current_link_color');
	$topnav_current_link_bg_color = get_option('solostream_topnav_current_link_bg_color');

	if ( $topnav_size )
		$topnav .= 'font-size:'.$topnav_size.';';
	if ( $topnav_weight )
		$topnav .= 'font-weight:'.$topnav_weight.';';
	if ( $topnav_font )
		$topnav .= 'font-family:'.$topnav_font.';';
	if ( $topnav_bg_color )
		$topnav .= 'background:'.$topnav_bg_color.';';

	if ( $topnav != '' )
		$output .= '#topnav,ul.nav ul a {'.$topnav.'}'. "\n";
		$output .= '#fixednav {'.$topnav.'}'. "\n";

	if ( $topnav_link_color )
		$output .= 'ul.nav a,ul.nav ul a {color:'.$topnav_link_color.';}' . "\n";
	if ( $topnav_link_hover_color )
		$output .= 'ul.nav a:hover,ul.nav ul a:hover {color:'.$topnav_link_hover_color.';}' . "\n";
	if ( $topnav_link_hover_bg_color )
		$output .= 'ul.nav a:hover,ul.nav ul a:hover {background-color:'.$topnav_link_hover_bg_color.';}' . "\n";

	if ( $topnav_current_link_color )
		$output .= 'ul.nav li.current-menu-parent > a,ul.nav li.current-menu-item > a,ul.nav li.current_page_item > a,ul.nav li li.current-menu-item > a,ul.nav li li.current-menu-item > a:hover,ul.nav li li.current_page_item > a,ul.nav li li.current_page_item > a:hover,ul.nav li li.current-menu-parent > a {color:'.$topnav_current_link_color.';}' . "\n";

	if ( $topnav_current_link_bg_color )
		$output .= 'ul.nav li.current-menu-parent > a,ul.nav li.current-menu-item > a,ul.nav li.current_page_item > a,ul.nav li li.current-menu-item > a,ul.nav li li.current-menu-item > a:hover,ul.nav li li.current_page_item > a,ul.nav li li.current_page_item > a:hover,ul.nav li li.current-menu-parent > a {background-color:'.$topnav_current_link_bg_color.';}' . "\n";

// Cat Navigation Adjustments

	$catnav = '';
	$catnav_size = get_option('solostream_catnav_size');
	$catnav_weight = get_option('solostream_catnav_weight');
	$catnav_font = get_option('solostream_catnav_font_family');
	$catnav_bg_color = get_option('solostream_catnav_bg_color');
	$catnav_link_color = get_option('solostream_catnav_link_color');
	$catnav_link_hover_color = get_option('solostream_catnav_link_hover_color');
	$catnav_link_hover_bg_color = get_option('solostream_catnav_link_hover_bg_color');
	$catnav_current_link_color = get_option('solostream_catnav_current_link_color');
	$catnav_current_link_bg_color = get_option('solostream_catnav_current_link_bg_color');

	if ( $catnav_size )
		$catnav .= 'font-size:'.$catnav_size.';';
	if ( $catnav_weight )
		$catnav .= 'font-weight:'.$catnav_weight.';';
	if ( $catnav_font )
		$catnav .= 'font-family:'.$catnav_font.';';
	if ( $catnav_bg_color )
		$catnav .= 'background-color:'.$catnav_bg_color.';';

	if ( $catnav != '' )
		$output .= '#catnav,#catnav ul ul a {border:0 !important;'.$catnav.'}'. "\n";

	if ( $catnav_link_color )
		$output .= '#catnav a,#catnav ul ul a {border:0 !important;color:'.$catnav_link_color.';}' . "\n";
	if ( $catnav_link_hover_color )
		$output .= '#catnav a:hover,#catnav ul ul a:hover {color:'.$catnav_link_hover_color.';}' . "\n";
	if ( $catnav_link_hover_bg_color )
		$output .= '#catnav a:hover,#catnav ul ul a:hover {background-color:'.$catnav_link_hover_bg_color.';}' . "\n";

	if ( $catnav_current_link_color )
		$output .= '#catnav li.current-menu-parent > a,#catnav li.current-menu-item > a,#catnav li.current_page_item > a,#catnav li li.current-menu-item > a,#catnav li li.current-menu-item > a:hover,#catnav li li.current_page_item > a,#catnav li li.current_page_item > a:hover,#catnav li li.current-menu-parent > a {color:'.$catnav_current_link_color.';}' . "\n";

	if ( $catnav_current_link_bg_color )
		$output .= '#catnav li.current-menu-parent > a,#catnav li.current-menu-item > a,#catnav li.current_page_item > a,#catnav li li.current-menu-item > a,#catnav li li.current-menu-item > a:hover,#catnav li li.current_page_item > a,#catnav li li.current_page_item > a:hover,#catnav li li.current-menu-parent > a {background-color:'.$catnav_current_link_bg_color.';}' . "\n";

// Main Content Adjustments

	$main_size = get_option('solostream_content_size');
	$main_link_color = get_option('solostream_content_link_color');
	$main_link_hover_color = get_option('solostream_content_link_hover_color');

	if ( $main_size )
		$output .= '.maincontent, #content {font-size:'.$main_size.';}' . "\n";
	if ( $main_link_color )
		$output .= '.maincontent a, .maincontent a:link, .maincontent a:visited, #content a, #content a:link, #content a:visited {color:'.$main_link_color.';}' . "\n";
	if ( $main_link_hover_color )
		$output .= '.maincontent a:hover, .maincontent a:active, #content a:hover, #content a:active {color:'.$main_link_hover_color.';}' . "\n";

// Sidebar-Right Adjustments

	$rt_sidebar_size = get_option('solostream_right_sidebar_size');
	$rt_sidebar_link_color = get_option('solostream_right_sidebar_link_color');
	$rt_sidebar_link_hover_color = get_option('solostream_right_sidebar_hover_link_color');
	$rt_sidebar_widgettitle_align = get_option('solostream_right_sidebar_widgettitle_align');

	if ( $rt_sidebar_size )
		$output .= '#contentright .widget {font-size:'.$rt_sidebar_size.';}' . "\n";
	if ( $rt_sidebar_link_color )
		$output .= '#contentright a, #contentright a:link, #contentright a:visited {color:'.$rt_sidebar_link_color.';}' . "\n";
	if ( $rt_sidebar_link_hover_color )
		$output .= '#contentright a:hover, #contentright a:active {color:'.$rt_sidebar_link_hover_color.';}' . "\n";
	if ( $rt_sidebar_widgettitle_align )
		$output .= '#sidebar h3.widgettitle, #sidebar-narrow h3.widgettitle {text-align:'.$rt_sidebar_widgettitle_align.';}' . "\n";

// Side Tabs Widget Adjustments

	$sidetabs = '';
	$sidetabs_size = get_option('solostream_sidetabs_size');
	$sidetabs_weight = get_option('solostream_sidetabs_weight');
	$sidetabs_font = get_option('solostream_sidetabs_font_family');
	$sidetabs_bg_color = get_option('solostream_sidetabs_bg_color');
	$sidetabs_link_color = get_option('solostream_sidetabs_link_color');
	$sidetabs_link_hover_color = get_option('solostream_sidetabs_link_hover_color');
	$sidetabs_link_hover_bg_color = get_option('solostream_sidetabs_link_hover_bg_color');
	$sidetabs_current_link_color = get_option('solostream_sidetabs_current_link_color');
	$sidetabs_current_link_bg_color = get_option('solostream_sidetabs_current_link_bg_color');

	if ( $sidetabs_size )
		$sidetabs .= 'font-size:'.$sidetabs_size.';';
	if ( $sidetabs_weight )
		$sidetabs .= 'font-weight:'.$sidetabs_weight.';';
	if ( $sidetabs_font )
		$sidetabs .= 'font-family:'.$sidetabs_font.';';
	if ( $sidetabs_bg_color )
		$sidetabs .= 'background-color:'.$sidetabs_bg_color.';';
	if ( $sidetabs_link_color )
		$output .= '.widget.sidetabs .flextabs-custom-controls a, .widget.sidetabs .flextabs-custom-controls a:link, .widget.sidetabs .flextabs-custom-controls a:visited {color:'.$sidetabs_link_color.' !important;}' . "\n";

	if ( $sidetabs != '' )
		$output .= '.widget.sidetabs .flextabs-custom-controls a, .widget.sidetabs .flextabs-custom-controls a:link, .widget.sidetabs .flextabs-custom-controls a:visited {'.$sidetabs.'}'. "\n";

	if ( $sidetabs_current_link_color )
		$output .= '.widget.sidetabs .flextabs-custom-controls a.flex-active, .widget.sidetabs .flextabs-custom-controls a.flex-active:link, .widget.sidetabs .flextabs-custom-controls a.flex-active:visited {color:'.$sidetabs_current_link_color.' !important;}' . "\n";

	if ( $sidetabs_current_link_bg_color )
		$output .= '.widget.sidetabs .flextabs-custom-controls a.flex-active, .widget.sidetabs .flextabs-custom-controls a.flex-active:link, .widget.sidetabs .flextabs-custom-controls a.flex-active:visited {background-color:'.$sidetabs_current_link_bg_color.';}' . "\n";

	if ( $sidetabs_link_color )
		$output .= '.widget.sidetabs .flextabs-custom-controls a.flex-active, .widget.sidetabs .flextabs-custom-controls a.flex-active:link, .widget.sidetabs .flextabs-custom-controls a.flex-active:visited {background-color:'.$sidetabs_current_link_bg_color.';}' . "\n";

// Button Colors

	$button_bg = get_option('solostream_button_bg');
	$button_font = get_option('solostream_button_font');
	$button_hover_bg = get_option('solostream_button_hover_bg');
	$button_hover_font = get_option('solostream_button_hover_font');

	if ( $button_bg )
		$output .= '#commentform input[type="submit"],#commentform input[type="button"],.archive-tabs a,.archive-tabs a:link,.archive-tabs a:visited,.email-form input[type="submit"],.email-form input[type="button"],#searchform input[type="submit"],#searchform input[type="button"],.wpcf7 input[type="submit"],.wpcf7 input[type="button"] {border-color:'.$button_bg.';background-color:'.$button_bg.' !important;}' . "\n";
	if ( $button_font )
		$output .= '#commentform input[type="submit"],#commentform input[type="button"],.archive-tabs a,.archive-tabs a:link,.archive-tabs a:visited,.email-form input[type="submit"],.email-form input[type="button"],#searchform input[type="submit"],#searchform input[type="button"],.wpcf7 input[type="submit"],.wpcf7 input[type="button"] {color:'.$button_font.' !important;}' . "\n";
	if ( $button_hover_bg )
		$output .= '#commentform input[type="submit"]:hover,#commentform input[type="button"]:hover,.archive-tabs a:hover,.archive-tabs a:active,.archive-tabs .ui-tabs-selected a,.email-form input[type="submit"]:hover,.email-form input[type="button"]:hover,#searchform input[type="submit"]:hover,#searchform input[type="button"]:hover,.wpcf7 input[type="submit"]:hover,.wpcf7 input[type="button"]:hover {border-color:'.$button_hover_bg.';background-color:'.$button_hover_bg.' !important;}' . "\n";
	if ( $button_hover_font )
		$output .= '#commentform input[type="submit"]:hover,#commentform input[type="button"]:hover,.archive-tabs a:hover,.archive-tabs a:active,.archive-tabs .ui-tabs-selected a,.email-form input[type="submit"]:hover,.email-form input[type="button"]:hover,#searchform input[type="submit"]:hover,#searchform input[type="button"]:hover,.wpcf7 input[type="submit"]:hover,.wpcf7 input[type="button"]:hover {color:'.$button_hover_font.' !important;}' . "\n";

// Footer Widgets Styles

	$footer_widgets = '';
	$footer_widgets_bg_color = get_option('solostream_footer_widgets_bg_color');
	$footer_widgets_font_color = get_option('solostream_footer_widgets_font_color');
	$footer_widgets_link_color = get_option('solostream_footer_widgets_link_color');
	$footer_widgets_link_hover_color = get_option('solostream_footer_widgets_link_hover_color');
	$footer_widgets_widgettitle_font_color = get_option('solostream_footer_widgets_widgettitle_font_color');

	if ( $footer_widgets_bg_color )
		$footer_widgets .= 'background-color:'.$footer_widgets_bg_color.' !important;';
	if ( $footer_widgets_font_color )
		$footer_widgets .= 'color:'.$footer_widgets_font_color.' !important;';

	if ( $footer_widgets != '' )
		$output .= '#footer-widgets, #footer-widgets .widget.subscribebox p.intro, #footer-widgets .widget.subscribebox p.priv-statement {'.$footer_widgets.'}'. "\n";

	if ( $footer_widgets_link_color )
		$output .= '#footer-widgets a, #footer-widgets a:link, #footer-widgets a:visited {color:'.$footer_widgets_link_color.' !important;}' . "\n";
	if ( $footer_widgets_link_hover_color )
		$output .= '#footer-widgets a:hover, #footer-widgets a:active {color:'.$footer_widgets_link_hover_color.' !important;}' . "\n";
	if ( $footer_widgets_widgettitle_font_color )
		$output .= '#footer-widgets h3.widgettitle {color:'.$footer_widgets_widgettitle_font_color.';}' . "\n";

// Footer and Footer Navigation Adjustments

	$footer = '';
	$footer_bg_color = get_option('solostream_footer_bg_color');
	$footer_font_color = get_option('solostream_footer_font_color');
	$footer_font_size = get_option('solostream_footer_font_size');
	$footer_link_color = get_option('solostream_footer_link_color');
	$footer_link_hover_color = get_option('solostream_footer_hover_link_color');

	if ( $footer_bg_color )
		$footer .= 'background:'.$footer_bg_color.';';
	if ( $footer_font_color )
		$footer .= 'color:'.$footer_font_color.';';
	if ( $footer_font_size )
		$footer .= 'font-size:'.$footer_font_size.';';

	if ( $footer != '' )
		$output .= '#footer {'.$footer.'}'. "\n";

	if ( $footer_link_color )
		$output .= '#footer a, #footer a:link, #footer a:visited, #footnav ul a, #footnav ul a:link, #footnav ul a:visited {color:'.$footer_link_color.';}' . "\n";
	if ( $footer_link_hover_color )
		$output .= '#footer a:hover, #footer a:active, #footnav ul a:hover, #footnav ul a:active {color:'.$footer_link_hover_color.';}' . "\n";

// Featured Content Read More Link Adjustments

	$featcontent = '';
	$featcontent_readmore_bg = get_option('solostream_featcontent_readmore_bg');
	$featcontent_readmore_color = get_option('solostream_featcontent_readmore_color');
	$featcontent_readmore_hover_bg = get_option('solostream_featcontent_readmore_hover_bg');
	$featcontent_readmore_hover_color = get_option('solostream_featcontent_readmore_hover_color');

	if ( $featcontent_readmore_bg )
		$featcontent .= 'background-color:'.$featcontent_readmore_bg.';';
	if ( $featcontent_readmore_color )
		$featcontent .= 'color:'.$featcontent_readmore_color.' !important;';

	if ( $featcontent != '' )
		$output .= '.featured.wide .myflexslider a.more-link, .featured.narrow .myflexslider a.more-link, .featured.cat .cat-container a.more-link {'.$featcontent.'}'. "\n";

	if ( $featcontent_readmore_hover_bg )
		$output .= '.featured.wide .myflexslider a.more-link:hover, .featured.narrow .myflexslider a.more-link:hover, .featured.cat .cat-container a.more-link:hover {background-color:'.$featcontent_readmore_hover_bg.';}';
	if ( $featcontent_readmore_hover_color )
		$output .= '.featured.wide .myflexslider a.more-link:hover, .featured.narrow .myflexslider a.more-link:hover, .featured.cat .cat-container a.more-link:hover {color:'.$featcontent_readmore_hover_color.' !important;}';

// Main Content Read More Link Adjustments

	$maincontent = '';
	$maincontent_readmore_bg = get_option('solostream_maincontent_readmore_bg');
	$maincontent_readmore_color = get_option('solostream_maincontent_readmore_color');
	$maincontent_readmore_hover_bg = get_option('solostream_maincontent_readmore_hover_bg');
	$maincontent_readmore_hover_color = get_option('solostream_maincontent_readmore_hover_color');

	if ( $maincontent_readmore_bg )
		$maincontent .= 'background-color:'.$maincontent_readmore_bg.';';
	if ( $maincontent_readmore_color )
		$maincontent .= 'color:'.$maincontent_readmore_color.' !important;';

	if ( $maincontent != '' )
		$output .= 'a.more-link, p.readmore a.more-link {'.$maincontent.'}'. "\n";

	if ( $maincontent_readmore_hover_bg )
		$output .= 'a.more-link:hover, p.readmore a.more-link:hover {background-color:'.$maincontent_readmore_hover_bg.';}';
	if ( $maincontent_readmore_hover_color )
		$output .= 'a.more-link:hover, p.readmore a.more-link:hover {color:'.$maincontent_readmore_hover_color.' !important;}';

// Output styles
	if ( $output ) {
		$output = "\n\n<!-- Custom Styles from Theme Setting Page -->\n<style type=\"text/css\">\n" . $output . "</style>\n";
		echo $output;
	}
}

/*-----------------------------------------------------------------------------------*/
// Add layout to body_class output
/*-----------------------------------------------------------------------------------*/

add_filter('body_class','solostream_layout_body_class');
function solostream_layout_body_class($classes) {

	$layout = '';
	$layout = get_option('solostream_layout');
	global $solostream_options;
	$solostream_options['solostream_layout'] = $layout;

	if (is_home()) {
		$page_id = get_option('page_for_posts');
		$layout = get_post_meta($page_id, 'layout', true);
		if ( !$layout || $layout == "Default" ) {
			$layout = get_option('solostream_layout_home');
		}
		global $solostream_options;
		$solostream_options['solostream_layout'] = $layout;
	}

	if ( is_single() ) {
		global $post;
		$layout = get_post_meta($post->ID, 'layout', true);
		if ( !$layout || $layout == "Default" ) {
			$layout = get_option('solostream_layout_post');
		}
		global $solostream_options;
		$solostream_options['solostream_layout'] = $layout;
	}

	if ( is_page() ) {
		global $post;
		$layout = get_post_meta($post->ID, 'layout', true);
		if ( !$layout || $layout == "Default" ) {
			$layout = get_option('solostream_layout_page');
		}
		global $solostream_options;
		$solostream_options['solostream_layout'] = $layout;
	}

	if ( is_archive() ) {
		$layout = get_option('solostream_layout_archive');
		global $solostream_options;
		$solostream_options['solostream_layout'] = $layout;
	}

	if ( is_404() ) {
		$layout = get_option('solostream_layout_404');
		global $solostream_options;
		$solostream_options['solostream_layout'] = $layout;
	}

	if ( is_page_template('page-landing.php') || is_page_template('page-alt-home.php') ) {
		$layout = "Full-Width";
		global $solostream_options;
		$solostream_options['solostream_layout'] = $layout;
	}

	if ( $layout == "Content | Sidebar-Wide" ) {
		$mybodyclass = "c-sw";
	} elseif ( $layout == "Sidebar-Wide | Content" ) {
		$mybodyclass = "sw-c";
	} elseif ( $layout == "Content | Sidebar-Narrow | Sidebar-Wide" ) {
		$mybodyclass = "c-sn-sw";
	} elseif ( $layout == "Sidebar-Narrow | Content | Sidebar-Wide" ) {
		$mybodyclass = "sn-c-sw";
	} elseif ( $layout == "Sidebar-Wide | Sidebar-Narrow | Content" ) {
		$mybodyclass = "sw-sn-c";
	} elseif ( $layout == "Sidebar-Wide | Content | Sidebar-Narrow" ) {
		$mybodyclass = "sw-c-sn";
	} elseif ( $layout == "Full-Width" ) {
		$mybodyclass = "fwidth";
	} elseif ( $layout == "Content | Sidebar-Narrow" ) {
		$mybodyclass = "c-sn";
	} elseif ( $layout == "Sidebar-Narrow | Content" ) {
		$mybodyclass = "sn-c";
	}

	// Add classes to body_class() output
	$classes[] = $mybodyclass;
	return $classes;
}

/*-----------------------------------------------------------------------------------*/
// Add hidetitle to body_class output
/*-----------------------------------------------------------------------------------*/

add_filter('body_class','solostream_hidetitle_body_class');
function solostream_hidetitle_body_class($classes) {

	global $post;
	$hidetitle = '';
	if ( is_singular() && get_post_meta($post->ID, 'hide_title', true) == "Yes" ) {
		$hidetitle = "hidetitle";
	}

	if ( $hidetitle ) {
		$classes[] = $hidetitle;
	}

	return $classes;

}

/*-----------------------------------------------------------------------------------*/
// Add centercatnav to body_class output
/*-----------------------------------------------------------------------------------*/

add_filter('body_class','solostream_centercatnav_body_class');
function solostream_centercatnav_body_class($classes) {

	global $post;
	$centercatnav = '';
	if ( is_singular() && get_post_meta($post->ID, 'centercatnav', true) == "Yes" || get_option('solostream_centercatnav') == "yes" ) {
		$centercatnav = "centercatnav";
	}

	if ( $centercatnav ) {
		$classes[] = $centercatnav;
	}

	return $classes;

}

?>