<?php

/*-----------------------------------------------------------------------------------*/
// This is theme Functions file (functions.php). You should avoid editing this file
// if possible. Instead, add new functions to theme-custom-functions.php.
/*-----------------------------------------------------------------------------------*/

/*-----------------------------------------------------------------------------------*/
// Action Hooks
/*-----------------------------------------------------------------------------------*/

// This hook executes just before the <body> tag
function solostream_before_body() { do_action('solostream_before_body'); }

// This hook executes just after the <body> tag
function solostream_after_body() { do_action('solostream_after_body'); }

// This hook executes just before the opening #wrap div tag
function solostream_before_wrap() { do_action('solostream_before_wrap'); }

// This hook executes just before the opening #page div tag
function solostream_before_page() { do_action('solostream_before_page'); }

// This hook executes just before the opening #contentleft div tag
function solostream_before_contentleft() { do_action('solostream_before_contentleft'); }

// This hook executes just before the closing #contentleft div tag
function solostream_before_close_contentleft() { do_action('solostream_before_close_contentleft'); }

// This hook executes just before the opening #content div tag
function solostream_before_content() { do_action('solostream_before_content'); }

// This hook executes just after the opening #content div tag
function solostream_after_open_content() { do_action('solostream_after_open_content'); }

/*-----------------------------------------------------------------------------------*/
// Add Featured Content Sliders to the site
/*-----------------------------------------------------------------------------------*/

// Add Featured Pages before opening #page div tag
add_action('solostream_before_page', 'featured_pages');

// Add Wide Featured Content before opening #page div tag
add_action('solostream_before_page', 'featured_wide');

// Add Narrow Content before opening #content div tag
add_action('solostream_after_open_content', 'featured_narrow');


/*-----------------------------------------------------------------------------------*/
// Various Functions to call Featured Content sliders
/*-----------------------------------------------------------------------------------*/

// Narrow Featured Content
function featured_narrow() {
	if (!is_404() && !is_search()) {
		$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
		global $wp_query;
		$postid = $wp_query->post->ID;
		if ( is_home() && $paged < 2 && get_option('solostream_features_on') == 'Narrow Width Featured Content Slider' ) {
			get_template_part( 'featured', 'narrow' );
		}
		if ( is_singular() && get_post_meta( $postid, 'post_featcontent', true ) == "Narrow Width Featured Content Slider" ) {
			get_template_part( 'featured', 'narrow' );
		}
	}
}

// Wide Featured Content
function featured_wide() {
	if (!is_404() && !is_search()) {
		$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
		global $wp_query;
		$postid = $wp_query->post->ID;
		if ( is_home() && $paged < 2 && get_option('solostream_features_on') == 'Full Width Featured Content Slider' ) {
			get_template_part( 'featured', 'wide' );
		}
		if ( is_singular() && get_post_meta( $postid, 'post_featcontent', true ) == "Full Width Featured Content Slider" ) {
			get_template_part( 'featured', 'wide' );
		}
	}
}

// Featured Pages
function featured_pages() {
	if (!is_404() && !is_search()) {
		$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
		global $wp_query;
		global $postid;
		$postid = $wp_query->post->ID;
		if ( is_home() && $paged < 2 && get_option('solostream_featpage_on') == 'Yes') {
			get_template_part( 'featured', 'pages' );
		}
		if ( is_singular() && get_post_meta( $postid, 'post_featpages', true ) == "Yes" ) {
			get_template_part( 'featured', 'pages' );
		}
	}
}

/*-----------------------------------------------------------------------------------*/
// Ready the theme for translation
/*-----------------------------------------------------------------------------------*/
add_action('after_setup_theme', 'solostream_theme_setup');
function solostream_theme_setup(){
	load_theme_textdomain('solostream');
}

/*-----------------------------------------------------------------------------------*/
// Require Various Files to Run the Theme
/*-----------------------------------------------------------------------------------*/
locate_template('theme-settings.php', true, true );
locate_template('theme-styles.php', true, true );
locate_template('theme-widgets.php', true, true );
locate_template('theme-metaboxes.php', true, true );
locate_template('theme-js.php', true, true );
locate_template('theme-images.php', true, true );
locate_template('theme-custom-functions.php', true, true );

/*-----------------------------------------------------------------------------------*/
// Register widgetized areas
/*-----------------------------------------------------------------------------------*/
add_action( 'init', 'theme_widgets_init' );
function theme_widgets_init() {
	register_sidebar(array (
		'name'=>'Sidebar-Wide - Top',
		'id'=>'widget-1',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Sidebar-Wide - Bottom Left',
		'id'=>'widget-2',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Sidebar-Wide - Bottom Right',
		'id'=>'widget-3',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Sidebar-Narrow',
		'id'=>'widget-4',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Footer Widget 1',
		'id'=>'widget-5',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Footer Widget 2',
		'id'=>'widget-6',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Footer Widget 3',
		'id'=>'widget-7',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Footer Widget 4',
		'id'=>'widget-8',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Alt Home Page Full-Width Top',
		'id'=>'widget-12',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Alt Home Page Left',
		'id'=>'widget-9',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Alt Home Page Middle',
		'id'=>'widget-10',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Alt Home Page Right',
		'id'=>'widget-11',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Alt Home Page Full-Width Bottom',
		'id'=>'widget-13',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Widgetized Page Full-Width Top',
		'id'=>'widget-14',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Widgetized Page Left',
		'id'=>'widget-15',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Widgetized Page Right',
		'id'=>'widget-17',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar(array (
		'name'=>'Widgetized Page Full-Width Bottom',
		'id'=>'widget-18',
		'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget' => '</div></div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
}


/*-----------------------------------------------------------------------------------*/
// Add "first" and "last" CSS classes to dynamic sidebar widgets. 
// Also adds numeric index class for each widget (widget-1, widget-2, etc.)
/*-----------------------------------------------------------------------------------*/

function widget_first_last_classes($params) {

	global $my_widget_num; // Global a counter array
	$this_id = $params[0]['id']; // Get the id for the current sidebar we're processing
	$arr_registered_widgets = wp_get_sidebars_widgets(); // Get an array of ALL registered widgets	

	if(!$my_widget_num) {// If the counter array doesn't exist, create it
		$my_widget_num = array();
	}

	if(!isset($arr_registered_widgets[$this_id]) || !is_array($arr_registered_widgets[$this_id])) { // Check if the current sidebar has no widgets
		return $params; // No widgets in this sidebar... bail early.
	}

	if(isset($my_widget_num[$this_id])) { // See if the counter array has an entry for this sidebar
		$my_widget_num[$this_id] ++;
	} else { // If not, create it starting with 1
		$my_widget_num[$this_id] = 1;
	}

	$class = 'class="widget widget-' . $my_widget_num[$this_id] . ' '; // Add a widget number class for additional styling options

	if($my_widget_num[$this_id] == 1) { // If this is the first widget
		$class .= 'widget-first ';
	} elseif($my_widget_num[$this_id] == count($arr_registered_widgets[$this_id])) { // If this is the last widget
		$class .= 'widget-last ';
	}

	$params[0]['before_widget'] = str_replace('class="widget ', $class, $params[0]['before_widget']); // Insert our new classes into "before widget"


	return $params;

}

add_filter('dynamic_sidebar_params','widget_first_last_classes');

/*-----------------------------------------------------------------------------------*/
// Add Excerpt field to Pages
/*-----------------------------------------------------------------------------------*/
add_post_type_support( 'page', 'excerpt' );

/*-----------------------------------------------------------------------------------*/
// Add RSS Feed Links
/*-----------------------------------------------------------------------------------*/
add_theme_support( 'automatic-feed-links' );

/*-----------------------------------------------------------------------------------*/
// Add support for WP 3.0 Menu Management
/*-----------------------------------------------------------------------------------*/
if (function_exists('add_theme_support')) {
	add_theme_support('menus');
}

/*-----------------------------------------------------------------------------------*/
// Register Nav Menus
/*-----------------------------------------------------------------------------------*/
if (function_exists('register_nav_menus')) {
	function register_my_menus() {
		register_nav_menus(array(
			'topnav' => __( 'Top Navigation', 'solostream' ),
			'catnav' => __( 'Secondary Navigation', 'solostream' ),
			'footernav' => __( 'Footer Navigation', 'solostream' ),
			'fixednav' => __( 'Fixed Navigation Bar', 'solostream' )
			)
		);
	}

	add_action( 'init', 'register_my_menus' );
}

/*-----------------------------------------------------------------------------------*/
// Fallback function for Top Navigation
/*-----------------------------------------------------------------------------------*/
function nav_fallback() {
	wp_list_pages('title_li=');
}

/*-----------------------------------------------------------------------------------*/
// Fallback function for Category Navigation
/*-----------------------------------------------------------------------------------*/
function catnav_fallback() {
	wp_list_categories('title_li=');
}

/*-----------------------------------------------------------------------------------*/
// Add Twitter and other social media links to user profile
/*-----------------------------------------------------------------------------------*/
add_filter('user_contactmethods','add_twitter_contactmethod',10,1);
function add_twitter_contactmethod( $contactmethods ) {
	$contactmethods['twitter'] = 'http://www.twitter.com/';
	$contactmethods['facebook'] = 'http://www.facebook.com/';
	$contactmethods['instagram'] = 'http://www.instagram.com/';
	$contactmethods['pinterest'] = 'http://pinterest.com/';
	$contactmethods['googbuzz'] = 'https://plus.google.com/';
	$contactmethods['linkedin'] = 'http://www.linkedin.com/in/';
	$contactmethods['linkedingroup'] = 'http://www.linkedin.com/groups/';
	$contactmethods['linkedin2'] = 'http://www.linkedin.com/';
	$contactmethods['flickr'] = 'http://www.flickr.com/photos/';
	$contactmethods['flickrgroup'] = 'http://www.flickr.com/groups/';
	$contactmethods['youtube'] = 'http://www.youtube.com/user/';

	return $contactmethods;
}

/*-----------------------------------------------------------------------------------*/
// Function to check for active Page Template File
/*-----------------------------------------------------------------------------------*/
function is_pagetemplate_active($pagetemplate = '') {
	global $wpdb;
	$sql = "select meta_key from $wpdb->postmeta where meta_key like '_wp_page_template' and meta_value like '" . $pagetemplate . "'";
	$result = $wpdb->query($sql);
	if ($result) {
		return TRUE;
	} else {
		return FALSE;
	}
}

/*-----------------------------------------------------------------------------------*/
// Function to get custom field value.
/*-----------------------------------------------------------------------------------*/
function get_custom_field($key, $echo = FALSE) {
	global $post;
	$custom_field = get_post_meta($post->ID, $key, true);
	if ($echo == FALSE) return $custom_field;
	echo $custom_field;
}

/*-----------------------------------------------------------------------------------*/
// Function to limit the number of words in the post excerpt.
/*-----------------------------------------------------------------------------------*/
function string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

/*-----------------------------------------------------------------------------------*/
// Function to list pings/trackbacks.
/*-----------------------------------------------------------------------------------*/
function list_pings($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
        <li id="comment-<?php comment_ID(); ?>"><?php comment_author_link(); ?> | <?php comment_date(); ?>
<?php }

/*-----------------------------------------------------------------------------------*/
// Function to add rel="nofollow" to the read more link.
/*-----------------------------------------------------------------------------------*/
function add_nofollow_to_more_links($content) {
	return preg_replace("@class=\"more-link\"@", "class=\"more-link\" rel=\"nofollow\"", $content);
}

add_filter('the_content', 'add_nofollow_to_more_links');

/*-----------------------------------------------------------------------------------*/
// Function to remove default border from gallery thumbnails
/*-----------------------------------------------------------------------------------*/
function remove_gallery_border( $galleryStyles ) {

	// Set the string we want to remove from the default style declaration.
	$remove = "border: 2px solid #cfcfcf;";

	// Remove it.
	$galleryStyles = str_replace( $remove, '', $galleryStyles );

	return $galleryStyles ;
}

add_filter( 'gallery_style', 'remove_gallery_border' );

/*-----------------------------------------------------------------------------------*/
// Function to get the post excerpt
/*-----------------------------------------------------------------------------------*/
function solostream_excerpt() {
	if ( get_option('solostream_post_content') == 'Excerpts' ) { ?>
		<?php the_excerpt(); ?>
		<p class="readmore"><a class="more-link" href="<?php the_permalink() ?>" rel="nofollow" title="<?php _e("Permanent Link to", "solostream"); ?> <?php the_title(); ?>"><?php _e("Read More &rarr;", "solostream"); ?></a></p>
	<?php } else {
		the_content(__("Read More &rarr;", "solostream"));
	}
}




/*-----------------------------------------------------------------------------------*/
// Function to call Fixed Navigation Bar (i.e. StickyNav)
/*-----------------------------------------------------------------------------------*/
function solostream_fixednav() {
	if (has_nav_menu('fixednav') && !is_page_template('page-landing.php') ) { ?>
		<!-- FIXED NAVBAR -->
		<div id="fixednav">
			<div class="limit clearfix">
				<!-- FIXED NAVIGATION MENU -->
				<ul class="fixednav">
					<?php wp_nav_menu(array('container'=>false,'theme_location'=>'fixednav','fallback_cb'=>'','items_wrap'=>'%3$s')); ?>
				</ul>
				<!-- SOCIAL MEDIA ICONS -->
				<?php get_template_part('sub-icons'); ?>
			</div>
		</div>
	<?php } 
}




/*-----------------------------------------------------------------------------------*/
// Function to call #topnav
/*-----------------------------------------------------------------------------------*/
function solostream_topnav() {
	if ( get_option('solostream_show_topnav') != 'no' && !is_page_template('page-landing.php') ) { ?>
		<!-- TOP NAVBAR -->
		<div id="topnav">
			<div class="limit clearfix">
				<?php if ( has_nav_menu('topnav') ) { ?>
					<!-- PRIMARY NAVIGATION -->
					<ul class="nav">
						<?php wp_nav_menu(array('container'=>false,'theme_location'=>'topnav','fallback_cb'=>'nav_fallback','items_wrap'=>'%3$s')); ?>
					</ul>
				<?php } ?>
				<!-- SOCIAL MEDIA ICONS -->
				<?php get_template_part('sub-icons'); ?>
			</div>
		</div>
	<?php }
}




/*-----------------------------------------------------------------------------------*/
// Function to call #header
/*-----------------------------------------------------------------------------------*/
function solostream_header() {
	if ( !is_page_template('page-landing.php') ) { ?>
		<div id="header" class="clearfix">
			<div id="head-content" class="clearfix">

				<!-- SITE-TITLE/LOGO -->
				<div id="sitetitle">
					<?php if ( get_option('solostream_site_title_option') == 'Image/Logo-Type Title' && get_option('solostream_site_logo_url') ) { ?>
						<a href="<?php echo home_url(); ?>" title="<?php bloginfo('name'); ?>"><img src="<?php echo get_option('solostream_site_logo_url'); ?>" alt="<?php bloginfo('name'); ?>" /></a>
					<?php } else { ?>
						<div class="title"><a href="<?php echo home_url(); ?>"><?php bloginfo('name'); ?></a></div>
						<div class="description"><?php bloginfo('description'); ?></div>
					<?php } ?>
				</div>

				<?php get_template_part('banner468head'); ?>

				<?php if ( get_option('solostream_show_catnav') == 'yes' ) { ?>
					<!-- SECONDARY NAVIGATION -->
					<div id="catnav">
						<ul class="catnav clearfix">
							<?php wp_nav_menu(array('container'=>false,'theme_location'=>'catnav','fallback_cb'=>'catnav_fallback','items_wrap'=>'%3$s')); ?>
						</ul>
					</div>
				<?php } ?>

			</div>
		</div>
	<?php }
}




/*-----------------------------------------------------------------------------------*/
// Add fixednav topnav and header before #wrap div
/*-----------------------------------------------------------------------------------*/
add_action('solostream_after_body', 'solostream_fixednav', 10);
add_action('solostream_before_wrap', 'solostream_topnav', 10);
add_action('solostream_before_wrap', 'solostream_header', 11);




/*-----------------------------------------------------------------------------------*/
// Add category nicenames in body and post class
/*-----------------------------------------------------------------------------------*/
function category_id_class($classes) {
	global $post;
	foreach((get_the_category($post->ID)) as $category)
		$classes[] = $category->cat_name;
       	 	return $classes;
}

add_filter('post_class', 'category_id_class');




/*-----------------------------------------------------------------------------------*/
// HIDE CERTAIN TAGS FROM TAG CLOUDS AND TAGS LISTS, ETC.
/*-----------------------------------------------------------------------------------*/

add_filter( 'get_terms', 'solo_hide_tags' );
function solo_hide_tags($terms) {
	global $user_ID;
	if ( is_admin() && $user_ID ) {
		// Logged in - show all terms
		return $terms;
	}
	// Trim out hidden terms
	$term_array = preg_split('/\s*,\s*/', strtolower('featured, featured-2, featured-3, full-image'));
	$terms_out = array();
	foreach ( $terms as $term ) {
		if ( !in_array($term->slug, $term_array) ) {
			$terms_out[] = $term;
		}
	}
	return $terms_out;
}

/*-----------------------------------------------------------------------------------*/
// HIDE CERTAIN TAGS FROM TAG LIST ON SINGLE POSTS.
/*-----------------------------------------------------------------------------------*/

add_filter('the_tags','solo_hide_post_tags');
function solo_hide_post_tags() {
	global $post;
	$links = array();
	$all_the_tags = get_the_tags();
	if ( $all_the_tags ) {
		foreach( $all_the_tags as $this_tag ) {
			if ( 
				$this_tag->slug != "featured" && 
				$this_tag->slug != "featured-2" &&
				$this_tag->slug != "featured-3" && 
				$this_tag->slug != "full-image" 
			) {
				$links[] = '<a rel="tag" href="'.get_tag_link($this_tag->term_id).'">'.$this_tag->name.'</a>';
			}
		}
	}
	if ( $links ) echo '<p class="tags">'. __('Tags', "solostream"). ': ';
	echo implode(', ', $links);
	if ($links) echo '</p>';
}

?>